# For the curious:
# 0.9.5a soversion = 0
# 0.9.6  soversion = 1
# 0.9.6a soversion = 2
# 0.9.6c soversion = 3
# 0.9.7a soversion = 4
# 0.9.7ef soversion = 5
# 0.9.8ab soversion = 6
%define soversion 6 

%global momorel 2 

# Number of threads to spawn when testing some threading fixes.
%define thread_test_threads %{?threads:%{threads}}%{!?threads:1}

# Arches on which we need to prevent arch conflicts on opensslconf.h, must
# also be handled in opensslconf-new.h.
%define multilib_arches %{ix86} ia64 ppc ppc64 s390 s390x x86_64

%define libicaversion 1.3.8

Summary: The OpenSSL toolkit.
Name: openssl
Version: 0.9.8e
Release: %{momorel}m%{?dist}
Source: ftp://ftp.openssl.org/source/openssl-%{version}.tar.gz
NoSource: 0
Source1: hobble-openssl
Source2: Makefile.certificate
Source3: ca-bundle.crt
Source4: https://rhn.redhat.com/help/RHNS-CA-CERT
Source5: https://rhn.redhat.com/help/RHNS-CA-CERT.asc
Source6: make-dummy-cert
# http://sourceforge.net/projects/opencryptoki/
Source7: libica-%{libicaversion}.tar.bz2
Source8: openssl-thread-test.c
Source9: opensslconf-new.h
Source10: opensslconf-new-warning.h
# Build changes
Patch0: openssl-0.9.8a-redhat.patch
Patch1: openssl-0.9.8a-defaults.patch
Patch2: openssl-0.9.8a-link-krb5.patch
Patch3: openssl-0.9.8b-soversion.patch
Patch4: openssl-0.9.8a-enginesdir.patch
Patch5: openssl-0.9.8a-no-rpath.patch
Patch25: libica-1.3.6-no-config-h.patch
# Functionality changes
Patch32: openssl-0.9.7-beta6-ia64.patch
Patch33: openssl-0.9.7f-ca-dir.patch
Patch34: openssl-0.9.6-x509.patch
Patch35: openssl-0.9.7-beta5-version-add-engines.patch
Patch38: openssl-0.9.8a-reuse-cipher-change.patch
Patch39: openssl-0.9.8b-ipv6-apps.patch
# Backported fixes including security fixes

# gcc-4.2 patch
Patch100:openssl-0.9.8e-gcc-4.2.patch

License: BSD
Group: System Environment/Libraries
URL: http://www.openssl.org/
BuildRoot: %{_tmppath}/%{name}-%{version}-root
BuildPreReq: mktemp, krb5-devel, perl, sed, zlib-devel, diffutils
Requires: mktemp

%description
The OpenSSL toolkit provides support for secure communications between
machines. OpenSSL includes a certificate management tool and shared
libraries which provide various cryptographic algorithms and
protocols.

%package devel
Summary: Files for development of applications which will use OpenSSL.
Group: Development/Libraries
Requires: %{name} = %{version}-%{release}, krb5-devel, zlib-devel

%description devel
OpenSSL is a toolkit for supporting cryptography. The openssl-devel
package contains static libraries and include files needed to develop
applications which support various cryptographic algorithms and
protocols.

%package perl
Summary: Perl scripts provided with OpenSSL.
Group: Applications/Internet
Requires: perl
Requires: %{name} = %{version}-%{release}

%description perl
OpenSSL is a toolkit for supporting cryptography. The openssl-perl
package provides Perl scripts for converting certificates and keys
from other formats to the formats used by the OpenSSL toolkit.

%prep
%setup -q

%{SOURCE1} > /dev/null
%patch0 -p1 -b .redhat
%patch1 -p1 -b .defaults
# Fix link line for libssl (bug #111154).
%patch2 -p1 -b .krb5
%patch3 -p1 -b .soversion
%patch4 -p1 -b .enginesdir
%patch5 -p1 -b .no-rpath

%patch32 -p1 -b .ia64
#patch33 is applied after make test
%patch34 -p1 -b .x509
%patch35 -p1 -b .version-add-engines
%patch38 -p1 -b .cipher-change
%patch39 -p1 -b .ipv6-apps

%patch100 -p1 -b .gcc42

# Modify the various perl scripts to reference perl in the right location.
perl util/perlpath.pl `dirname %{__perl}`

# Generate a table with the compile settings for my perusal.
# add sleep for tmpfs build
sleep 1
touch Makefile
make TABLE PERL=%{__perl}

%build 
# Figure out which flags we want to use.
# default
sslarch=%{_os}-%{_arch}
%ifarch %ix86
sslarch=linux-elf
if ! echo %{_target} | grep -q i686 ; then
	sslflags="no-asm 386"
fi
%endif
%ifarch sparc
sslarch=linux-sparcv9
sslflags=no-asm
%endif
%ifarch alpha
sslarch=linux-alpha-gcc
%endif
%ifarch s390
sslarch="linux-generic32 -DB_ENDIAN -DNO_ASM"
%endif
%ifarch s390x
sslarch="linux-generic64 -DB_ENDIAN -DNO_ASM"
%endif
# ia64, x86_64, ppc, ppc64 are OK by default
# Configure the build tree.  Override OpenSSL defaults with known-good defaults
# usable on all platforms.  The Configure script already knows to use -fPIC and
# RPM_OPT_FLAGS, so we can skip specifiying them here.
./Configure \
	--prefix=%{_prefix} --openssldir=%{_sysconfdir}/pki/tls ${sslflags} \
	zlib no-idea no-mdc2 no-rc5 no-ec no-ecdh no-ecdsa shared \
	--with-krb5-flavor=MIT --enginesdir=%{_libdir}/openssl/engines \
	-I%{_prefix}/kerberos/include -L%{_prefix}/kerberos/%{_lib} \
	${sslarch}

# Add -Wa,--noexecstack here so that libcrypto's assembler modules will be
# marked as not requiring an executable stack.
RPM_OPT_FLAGS="$RPM_OPT_FLAGS -Wa,--noexecstack"
make depend
make all build-shared

# Generate hashes for the included certs.
make rehash build-shared

# Verify that what was compiled actually works.
LD_LIBRARY_PATH=`pwd`${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
export LD_LIBRARY_PATH
make -C test apps tests
%{__cc} -o openssl-thread-test \
	`krb5-config --cflags` \
	-I./include \
	$RPM_OPT_FLAGS \
	%{SOURCE8} \
	-L. \
	-lssl -lcrypto \
	`krb5-config --libs` \
	-lpthread -lz -ldl
./openssl-thread-test --threads %{thread_test_threads}

# Patch33 must be patched after tests otherwise they will fail
patch -p1 -b -z .ca-dir < %{PATCH33}

%install
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot}
# Install OpenSSL.
install -d %{buildroot}/{%{_lib},%{_bindir},%{_includedir},%{_libdir},%{_mandir},%{_libdir}/openssl}
make INSTALL_PREFIX=%{buildroot} install build-shared
mv %{buildroot}/usr/lib/lib*.so.%{soversion} %{buildroot}/%{_lib}/
mv %{buildroot}/usr/lib/engines %{buildroot}/%{_libdir}/openssl
mv %{buildroot}%{_sysconfdir}/pki/tls/man/* %{buildroot}%{_mandir}/
rmdir %{buildroot}%{_sysconfdir}/pki/tls/man
mv %{buildroot}/usr/lib/* %{buildroot}%{_libdir}/ || :
rename so.%{soversion} so.%{version} %{buildroot}/%{_lib}/*.so.%{soversion}
for lib in %{buildroot}/%{_lib}/*.so.%{version} ; do
	chmod 755 ${lib}
	ln -s -f ../../%{_lib}/`basename ${lib}` %{buildroot}%{_libdir}/`basename ${lib} .%{version}`
	ln -s -f `basename ${lib}` %{buildroot}/%{_lib}/`basename ${lib} .%{version}`.%{soversion}
	rm -f %{buildroot}%{_libdir}/`basename ${lib} .%{version}`.%{soversion}
done

# Install a makefile for generating keys and self-signed certs, and a script
# for generating them on the fly.
mkdir -p %{buildroot}%{_sysconfdir}/pki/tls/certs
install -m644 $RPM_SOURCE_DIR/Makefile.certificate %{buildroot}%{_sysconfdir}/pki/tls/certs/Makefile
install -m644 $RPM_SOURCE_DIR/make-dummy-cert      %{buildroot}%{_sysconfdir}/pki/tls/certs/make-dummy-cert

# Make sure we actually include the headers we built against.
for header in %{buildroot}%{_includedir}/openssl/* ; do
	if [ -f ${header} -a -f include/openssl/$(basename ${header}) ] ; then
		install -m644 include/openssl/`basename ${header}` ${header}
	fi
done

# Rename man pages so that they don't conflict with other system man pages.
for manpage in %{buildroot}%{_mandir}/man*/* ; do
	if [ -L ${manpage} ]; then
		TARGET=`ls -l ${manpage} | awk '{ print $NF }'`
		ln -snf ${TARGET}ssl ${manpage}ssl
		rm -f ${manpage}
	else
		mv ${manpage} ${manpage}ssl
	fi
done
for conflict in passwd rand ; do
	rename ${conflict} ssl${conflict} %{buildroot}%{_mandir}/man*/${conflict}*
done

# Pick a CA script.
pushd  %{buildroot}%{_sysconfdir}/pki/tls/misc
mv CA.sh CA
popd

mkdir -m700 %{buildroot}%{_sysconfdir}/pki/CA
mkdir -m700 %{buildroot}%{_sysconfdir}/pki/CA/private

# Install root CA stuffs.
cat << EOF > RHNS-blurb.txt
#
#  RHNS CA certificate.  Appended to the ca-bundle at package build-time.
#
EOF
cat %{SOURCE3} RHNS-blurb.txt %{SOURCE4} > ca-bundle.crt
install -m644 ca-bundle.crt %{buildroot}%{_sysconfdir}/pki/tls/certs/
ln -s certs/ca-bundle.crt %{buildroot}%{_sysconfdir}/pki/tls/cert.pem

# Fix libdir.
pushd %{buildroot}/%{_libdir}/pkgconfig
for i in *.pc ; do
	sed 's,^libdir=${exec_prefix}/lib,libdir=${exec_prefix}/%{_lib},g' \
	    $i >$i.tmp && \
	cat $i.tmp >$i && \
	rm -f $i.tmp
done
popd

# Determine which arch opensslconf.h is going to try to #include.
basearch=%{_arch}
%ifarch %{ix86}
basearch=i386
%endif

%ifarch %{multilib_arches}
# Do an opensslconf.h switcheroo to avoid file conflicts on systems where you
# can have both a 32- and 64-bit version of the library, and they each need
# their own correct-but-different versions of opensslconf.h to be usable.
install -m644 %{SOURCE10} \
   %{buildroot}/%{_prefix}/include/openssl/opensslconf-${basearch}.h
cat %{buildroot}/%{_prefix}/include/openssl/opensslconf.h >> \
   %{buildroot}/%{_prefix}/include/openssl/opensslconf-${basearch}.h
install -m644 %{SOURCE9} \
   %{buildroot}/%{_prefix}/include/openssl/opensslconf.h
%endif

%ifarch %{optimize_arches}
# Remove bits which belong in subpackages.
rm -rf $RPM_BUILD_ROOT/%{_prefix}/include/openssl
rm -rf $RPM_BUILD_ROOT/%{_libdir}/*.a
rm -rf $RPM_BUILD_ROOT/%{_libdir}/*.so
rm -rf $RPM_BUILD_ROOT/%{_libdir}/pkgconfig
rm -rf $RPM_BUILD_ROOT/%{_mandir}/man3/*

rm -rf $RPM_BUILD_ROOT/%{_bindir}/c_rehash
rm -rf $RPM_BUILD_ROOT/%{_mandir}/man1*/*.pl*
rm -rf $RPM_BUILD_ROOT/%{_sysconfdir}/pki/tls/misc/*.pl
%endif

# Remove fips fingerprint script 
rm -rf $RPM_BUILD_ROOT/%{_bindir}/openssl_fips_fingerprint

%clean
[ "%{buildroot}" != "/" ] && rm -rf %{buildroot}

%files 
%defattr(-,root,root)
%doc FAQ LICENSE CHANGES NEWS INSTALL README
%doc doc/README doc/c-indentation.el doc/openssl.txt
%doc doc/openssl_button.html doc/openssl_button.gif
%doc doc/ssleay.txt
%dir %{_sysconfdir}/pki/tls
%dir %{_sysconfdir}/pki/tls/certs
%{_sysconfdir}/pki/tls/certs/make-dummy-cert
%{_sysconfdir}/pki/tls/certs/Makefile
%{_sysconfdir}/pki/tls/cert.pem
%dir %{_sysconfdir}/pki/tls/misc
%{_sysconfdir}/pki/tls/misc/CA
%dir %{_sysconfdir}/pki/CA
%dir %{_sysconfdir}/pki/CA/private
%{_sysconfdir}/pki/tls/misc/c_*
%{_sysconfdir}/pki/tls/private

%config(noreplace) %{_sysconfdir}/pki/tls/openssl.cnf
%config(noreplace) %{_sysconfdir}/pki/tls/certs/ca-bundle.crt

%attr(0755,root,root) %{_bindir}/openssl
%attr(0755,root,root) /%{_lib}/*.so.%{version}
%attr(0755,root,root) /%{_lib}/*.so.%{soversion}
%attr(0755,root,root) %{_libdir}/openssl
%attr(0644,root,root) %{_mandir}/man1/[ABD-Zabcd-z]*
%attr(0644,root,root) %{_mandir}/man5/*
%attr(0644,root,root) %{_mandir}/man7/*
%ifarch s390 s390x
%attr(0755,root,root) %{_libdir}/libica.so
%endif

%files devel
%defattr(-,root,root)
%{_prefix}/include/openssl
%ifarch s390 s390x
%{_includedir}/*.h
%endif
%attr(0644,root,root) %{_libdir}/*.a
%attr(0755,root,root) %{_libdir}/*.so
%attr(0644,root,root) %{_mandir}/man3/*
%attr(0644,root,root) %{_libdir}/pkgconfig/*.pc

%files perl
%defattr(-,root,root)
%attr(0755,root,root) %{_bindir}/c_rehash
%attr(0644,root,root) %{_mandir}/man1*/*.pl*
%{_sysconfdir}/pki/tls/misc/*.pl

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%changelog
* Thu Mar 15 2007 Yohsuke Ooi <meke@momonga-linux.org>
- (0.9.8e-2m)
- Fix gcc-4.2
-- Patch100:openssl-0.9.8e-gcc-4.2.patch

* Sun Mar  4 2007 Shigeru Yamazaki <muradaikan@momonga-linux.org>
- (0.9.8e-1m)
- update Sources:
  Source: openssl-0.9.8e.tar.gz
  Source7: libica-1.3.8.tar.bz2
- removed patches:
  Patch24: openssl-0.9.8a-padlock.patch
  Patch36: openssl-0.9.8a-use-poll.patch
  Patch40: openssl-0.9.8b-enc-bufsize.patch
  Patch51: openssl-0.9.8b-block-padding.patch
  Patch52: openssl-0.9.8b-pkcs12-fix.patch
  Patch53: openssl-0.9.8b-bn-threadsafety.patch
  Patch54: openssl-0.9.8b-aes-cachecol.patch
  Patch55: openssl-0.9.8b-pkcs7-leak.patch
  Patch56: openssl-0.9.8b-cve-2006-4339.patch
  Patch57: openssl-0.9.8b-cve-2006-2937.patch
  Patch58: openssl-0.9.8b-cve-2006-2940.patch
  Patch59: openssl-0.9.8b-cve-2006-3738.patch
  Patch60: openssl-0.9.8b-cve-2006-4343.patch
- soversion unchanged but may have to be incremented 

* Mon Oct  2 2006 YONEKAWA Susumu <yonekawas@mmg.roka.jp>
- (0.9.8b-6m)
- revised changelog and postuninstall scripts

* Sat Sep 30 2006 Ryu SASAOKA <ryu@momonga-linux.org>
- (0.9.8b-5m)
- [SECURITY] CVE-2006-2937 CVE-2006-2940 CVE-2006-3738 CVE-2006-4343
- http://www.openssl.org/news/secadv_20060928.txt
- import patch from FC-devel

* Fri Sep  9 2006 Masahiro Takahata <takahata@momonga-linux.org>
- (0.9.8b-4m)
- import patch from FC-devel
- [SECURITY] fix CVE-2006-4339 - prevent attack on PKCS#1 v1.5 signatures

* Sat Jun 10 2006 Masahiro Takahata <takahata@momonga-linux.org>
- (0.9.8b-3m)
- delete duplicate file

* Sat May 13 2006 KAJIWARA, Atsushi <kajiwara@noguard.org>
- (0.9.8b-2m)
- sync with fc-devel

* Tue May 09 2006 KAJIWARA, Atsushi <kajiwara@noguard.org>
- (0.9.8b-1m)
- version up
- add patch23,24 from fc-devel

* Sun Apr  9 2006 TABUCHI Takaaki <tab@momonga-linux.org>
- (0.9.8a-2m)
- add sleep 1 before touch Makefile for tmpfs build

* Sun Apr  9 2006 Masahiro Takahata <takahata@momonga-linux.org>
- (0.9.8a-1m)
- upgrade 0.9.8a
- import from fc5

* Fri Feb 24 2006 Ryu SASAOKA <ryu@momonga-linux.org>
- (0.9.7i-1m)
- [SECURITY] CVE-2005-2969
- http://www.st.ryukoku.ac.jp/%7Ekjm/security/memo/2005/10.html#20051012_OpenSSL
- http://www.openssl.org/news/secadv_20051011.txt
- update to 0.9.7i

* Sat May 28 2005 Kazuhiko <kazuhiko@fdiary.net>
- (0.9.7g-2m)
- remove '%%{_libdir}/libcrypto.so.*'

* Tue Apr 12 2005 Masahiro Takahata <takahata@momonga-linux.org>
- (0.9.7g-1m)
- upgrade 0.9.7g

* Tue Mar 29 2005 TAKAHASHI Tamotsu <tamo>
- (0.9.7f-1m)
- From NEWS:
  + Improved comparison of X509 Name type.
  + Mandatory basic checks on certificates.
- openssl-cflags.patch needs more checking,
  for ppc/ppc64 in particular!
- der_chop has been removed from the distribution.
- libfips is not installed. no need to remove it.
- Remove openssl-0.9.7a-missing-header.patch.
  Please re-apply it if necessary, tom-san.
- Update Makefile.certificate:
  + Thu Feb 10 2005 Tomas Mraz <tmraz@redhat.com>
  - Support UTF-8 charset in the Makefile.certificate (#134944)
- Update ca-bundle.crt:
  + Thu Jan 27 2005 Joe Orton <jorton@redhat.com> 0.9.7a-46
  - generate new ca-bundle.crt from Mozilla certdata.txt (revision 1.32)

* Fri Jan 14 2005 Toru Hoshina <t@momonga-linux.org>
- (0.9.7e-3m)
- enable x86_64.

* Wed Dec  8 2004 TAKAHASHI Tamotsu <tamo>
- (0.9.7e-2m)
- apply derchop_tmpfile.patch to der_chop.in

* Wed Dec  8 2004 TAKAHASHI Tamotsu <tamo>
- (0.9.7e-1m)
- update
 - remove openssl-0.9.7d-pk7.patch
 - there is not 'Modes of DES' manual but 'Modes_of_DES'
 - libdir/pkgconfig is a directory, libdir/pkgconfig/openssl.pc is a file
 - there is no openssldir/lib
 - there is not crypto/bn/Makefile.ssl but crypto/bn/Makefile
  - what is the purpose of Patch1? (openssl-0.9.7a-missing-header.patch)
- CAN-2004-0975: do not use insecure temporary files
 (Patch2: openssl-0.9.7e-derchop_tmpfile.patch)

* Wed Sep 29 2004 YAMAZAKI Makoto <zaki@zakky.org>
- (0.9.7d-3m)
- used shell variable instead of rpm macro

* Fri Jun 25 2004 TAKAHASHI Tamotsu <tamo>
- (0.9.7d-2m)
- apply http://cvs.openssl.org/filediff?f=openssl/crypto/pkcs7/pk7_doit.c&v1=1.50.2.8&v2=1.50.2.9
 see http://www.mail-archive.com/openssl-dev@openssl.org/msg17377.html
 You cannot S/MIME-encrypt messages without this patch!

* Wed Mar 17 2004 Kazuhiko <kazuhiko@fdiary.net>
- (0.9.7d-1m)
- including DoS fix
- http://www.openssl.org/news/secadv_20040317.txt

* Wed Dec 17 2003 YONEKAWA Susumu <yonekawa@mmg.roka.jp>
- (0.9.7c-5m)
- add openssl-0.9.7c-pod-fix.patch
  patch missing comma to doc/crypto/EVP_DigestInit.pod and doc/crypto/ui.pod
  This has already fixed in snapshot version
  http://www.mail-archive.com/openssl-dev@openssl.org/msg16352.html

* Mon Oct 27 2003 Kenta MURATA <muraken2@nifty.com>
- (0.9.7c-4m)
- devel package includes LICENSE.
- pretty spec file.

* Tue Oct  7 2003 Kazuhiko <yohgaki@momonga-linux.org>
- (0.9.7c-3m)
- add openssl.pc 

* Sun Oct  5 2003 Kazuhiko <kazuhiko@fdiary.net>
- (0.9.7c-2m)
- mv Modes\ of\ DES.7 Modes_of_DES.7

* Tue Sep 30 2003 zunda <zunda at freeshell.org>
- (0.9.7c-1m)
- [security] fix for DOS and remote code execution vulnerability
  http://www.uniras.gov.uk/vuls/2003/006489/openssl.htm

* Mon Jul 28 2003 Masahiro Takahata <takahata@momonga-linux.org>
- (0.9.7b-2m)
- modify %define openssldir %{_datadir}/ssl

* Mon Apr 14 2003 HOSONO Hidetomo <h12o@h12o.org>
- (0.9.7b-1m)
- remove openssl-TimingAttack.patch (Patch2)
  and openssl-0.9.7a-Klima_Pokorny_Rosa.patch (Patch3)

* Sun Mar 23 2003 KOMATSU Shinichiro <koma2@momonga-linux.org>
- (0.9.7a-4m)
- [security] Klima-Pokorny-Rosa attack on RSA in SSL/TLS
  http://www.openssl.org/news/secadv_20030319.txt

* Tue Mar 18 2003 Tsutomu Yasuda <tom@tom.homelinux.org>
- (0.9.7a-3m)
  fix symbolic link
  security fix
  http://www.securityfocus.com/archive/1/315292/2003-03-15/2003-03-21/0
  http://www.openssl.org/news/secadv_20030317.txt

* Sun Mar  8 2003 Tsutomu Yasuda <tom@tom.homelinux.org>
- (0.9.7a-2m)
  add bn_lcl.h

* Wed Mar  5 2003 Tsutomu Yasuda <tom@tom.homelinux.org>
- (0.9.7a-1m)
  update to 0.9.7a

* Thu Feb 20 2003 HOSONO Hidetomo <h12o@h12o.org>
- (0.9.6i-1m)
- version up

* Sat Dec  7 2002 HOSONO Hidetomo <h12o@h12o.org>
- (0.9.6h-1m)
- version up

* Tue Dec  3 2002 Kazuhiko <kazuhiko@fdiary.net>
- (0.9.6g-3m)
- drop '-fstack-protector' instead of '-fomit-frame-pointer'

* Tue Dec  3 2002 YAMAZAKI Makoto <uomaster@nifty.com>
- (0.9.6g-2m)
- drop -fomit-frame-pointer to resolve [Momonga-devel.ja:00956]

* Mon Aug 12 2002 Shigeyuki Yamashita <shige@cty-net.ne.jp>
- (0.9.6g-1m)
- update to 0.9.6g

* Wed Aug  7 2002 KOMATSU Shinichiro <koma2@jiro.c.u-tokyo.ac.jp>
- (0.9.6e-2m)
- [security] Add Patch10 (openssl-0.9.6e-asn1.diff)
  This patch fixes the ASN.1 vulnerability.
  Ref. http://rhn.redhat.com/errata/RHSA-2002-160.html
- on alpha*, do not use ./config, use ./Configure instead,
  because shared library is not built if ccc is installed.
- delete Patch1 (openssl-alphaev5.patch)
  since ./config is no longer used on alpha*
- modify openssl-cflags.patch so as to
  make command line arguments have higher priority
  than ./Configure's default one.
- modify openssl-cflags.patch to build on sparc
  (assembler is disabled).

* Tue Jul 30 2002 HOSONO Hidetomo <h@h12o.org>
- (0.9.6e-1m)
- version up (openssl-0.9.6e includes a security fix)
- a fix of openssl-cflags.patch

* Fri May 17 2002 HOSONO Hidetomo <h@kondara.org>
- (0.9.6d-4k)
- a fix of openssl-cflags.patch
  and openssl-0.9.6d-Configure.patch is not needed(...).

* Wed May 15 2002 HOSONO Hidetomo <h@kondara.org>
- (0.9.6d-2k)
- update to 0.9.6d
- update openssl-cflags.patch
- add openssl-0.9.6d-Configure.patch for Configure script bug fix

* Fri Mar  8 2002 Tsutomu Yasuda <tom@kondara.org>
- (0.9.6c-2k)
- update to 0.9.6c

* Thu Nov  8 2001 Masahiro Takahata <takahata@kondara.org>
- (0.9.6b-6k)
- import from rawhide(Makefile.certificate make-dummy-cert)
- import from mod_ssl(ca-bundle.crt)

* Mon Aug  3 2001 Toru Hoshina <toru@df-usa.com>
- (0.9.6b-4k)
- force ev5 for alphaev5.

* Sun Jul 15 2001 MATSUDA, Daiki <dyky@df-usa.com>
- (0.9.6b-2k)
- update to 0.9.6b for security fix

* Wed Apr 11 2001 Tsutomu Yasuda <tom@digitalfactory.co.jp>
- update to 0.9.6a

* Thu Oct 12 2000 Tsutomu Yasuda <tom@digitalfactory.co.jp>
- update to 0.9.6
- no-rc5 no-idea
* Wed Apr 19 2000 Tenkou N. Hattori <tnh@kondara.org>
- kondarize.
* Sun Feb 27 2000 Damien Miller <djm@mindrot.org>
- Merged patches to spec
- Updated to 0.9.5beta2 (now with manpages)
* Sat Feb  5 2000 Michal Jaegermann <michal@harddata.com>
- added 'linux-alpha' to configuration
- fixed nasty absolute links
* Tue Jan 25 2000 Bennett Todd <bet@rahul.net>
- Added -DSSL_ALLOW_ADH, bumped Release to 4
* Thu Oct 14 1999 Damien Miller <djm@mindrot.org>
- Set default permissions
- Removed documentation from devel sub-package
* Thu Sep 30 1999 Damien Miller <djm@mindrot.org>
- Added "make test" stage
- GPG signed
* Tue Sep 10 1999 Damien Miller <damien@ibs.com.au>
- Updated to version 0.9.4
* Tue May 25 1999 Damien Miller <damien@ibs.com.au>
- Updated to version 0.9.3
- Added attributes for all files
- Paramatised openssl directory
* Sat Mar 20 1999 Carlo M. Arenas Belon <carenas@jmconsultores.com.pe>
- Added "official" bnrec patch and taking other out
- making a link from ssleay to openssl binary
- putting all changelog together on SPEC file
* Fri Mar  5 1999 Henri Gomez <gomez@slib.fr>
- Added bnrec patch
* Tue Dec 29 1998 Jonathan Ruano <kobalt@james.encomix.es>
- minimum spec and patches changes for openssl
- modified for openssl sources
* Sat Aug  8 1998 Khimenko Victor <khim@sch57.msk.ru>
- shared library creating process honours %{optflags}
- shared libarry supports threads (as well as static library)
* Wed Jul 22 1998 Khimenko Victor <khim@sch57.msk.ru>
- building of shared library completely reworked
* Tue Jul 21 1998 Khimenko Victor <khim@sch57.msk.ru>
- RPM is BuildRoot'ed
* Tue Feb 10 1998 Khimenko Victor <khim@sch57.msk.ru>
- all stuff is moved out of /usr/local
